#  TMC_seg015_DefaultSettings.R 
#  (c) wwosniok@math.uni-bremen.de

#  Truncated minimum chi-square estimation
#
#  Segment containing expert settings

#  TODO       
#  -  

#  #  CHANGE HISTORY
#  23.04.2021 Standard settings changed:n.per.bin.min, bins.n.min, bins.n.max,
#             x.tr.bins.min
#  10.04.2021 Standard settings changed: n.per.bin.min, crit6p
#  10.04.2021 package mgcv added
#  30.03.2021 Default for max daytime of analysis changed to 24:00
#  09.03.2021 Required packages are automatically loaded from repository
#             Uni Mnster
#  26.01.2021 All external functions in /func compiled as seg022. See
#             CompileFunctions in /func.
#  25.01.2021 crit123456 and crit6.p added
#  14.01.2021 r.fact added
#  10.01.2021 Default settings according to experimentation results from
#             2021-01-09-170753  
#  28.12.2020 bins.n.max introduced
#  18.12.2020 Experimental function moved to ../func/ and automatically read
#             from there
#  04.12.2020 Options for histogram smoothing added
#  18.11.2020 Transform.KDE added
#  14.11.2020 bins.n.min  added. Is the same as x.bins.min. @@ One of these 
#             should be removed.
#  10.11.2020 Additional experimental functions source in
#  21.07.2020 Limits for KDE now set here
#  16.07.2020 Global parameters for tickmark label orientation and position
#             and detail plotting y/n
#  20.05.2020 x.tr.prop.max set to 0.85 as new default
#  13.05.2020 x.bin.min.min introduced to deal with few bins due to rounding
#  27.04.2020 DL.options introduced, loading of functions moved to here
#  21.04.2020 Loading of libraries move here to allow use in start programme
#  20.04.2020 Split by date introduced
#  10.04.2020 Surrogate factor s.fact introduced
#  30.03.2020 new standards for x.tr.prop.min, x.tr.prop.max, p.fit.min 
#  03.03.2020 n.bin.min replaced by x.bins.min
#  26.02.2020 New components for Doan calculation of bin size
#  25.02.2020 Call moved before user input. All parameters may be set here
#             and afterwards changed by the user. No user input means no 
#             change of default setting. All settings are processed by 
#             050_Master.
#  26.01.2017 absolut limit for the upper limit of the truncation interval 
#             introduced
#    .01.2020 pathol.position re-introduced, effective for LR only 
#  10.01.2020 pathol.position deleted
#             Parameters for RL axis n 150.010, 160.010 introduced
#  03.01.2020 Var names changed to new standard
#  21.12.2019 Default value for use.dev corrected
#  01.12.2019 Additional parameter for histogram smoothing added
#  17.09.2019 Factor for penalty term 'negative prevelance" introduced
#  28.08.2019 p.fit.min introduced
#  27.08.2019 prop.tmc.seq defined alternatively
#  19.07.2019 use.oh moved to Start file
#  13.07.2019 Expert input input moved from Start to here
#  12.05.2019 plot.details1920 introduced
#  11.03.2019 Start from WWW17_seg25_master  (directory ProgWW17_RH)

# ===========================================================================

if (print.log.message) { cat("%%%   TMC_seg15_DefaultSettings  Start\n") }

# ==========================================================================

#  Record start time
time.start <- Sys.time()     #  "2020-02-26 11:55:02 CET"
                             #   12345678901234567890123
                             #            11111111112222 

# ===========================================================================
#  Packages

#  Set repository from wich packages are to be loaded
repos <- "https://cran.uni-muenster.de/"

# ...........................................................................
#  Try to load package date
date.loaded <- require(date)

# if load was not successful, then date.loaded == FALSE
if (!date.loaded)
{ 
  install.packages("date", dependencies=TRUE, repos=repos)
}
library(date)

# ...........................................................................
#  Try to load package mgcv  (for gam according to Simon Wood)
mgcv.loaded <- require(mgcv)

# if load was not successful, then mgcv.loaded == FALSE
if (!mgcv.loaded)
{ 
  install.packages("mgcv", dependencies=TRUE, repos=repos) 
}
library(mgcv)

# ...........................................................................
#  Try to load package modeest
modeest.loaded <- require(modeest)

# if load was not successful, then modeest.loaded == FALSE
if (!modeest.loaded)
{ 
  install.packages("modeest", dependencies=TRUE, repos=repos) 
}
library(modeest)

# ...........................................................................
#  Try to load package snpar
snpar.loaded <- require(snpar)

# if load was successful, then snpar.loaded == FALSE
if (!snpar.loaded)
{ 
  install.packages("snpar", dependencies=TRUE, repos=repos) 
}
library(snpar)

# ...........................................................................
#  Try to load package stringr
stringr.loaded <- require(stringr)

# if load was successful, then stringr.loaded == FALSE
if (!stringr.loaded)
{ 
  install.packages("stringr", dependencies=TRUE, repos=repos) 
}
library(stringr)

# ---------------------------------------------------------------------------

#  Load styles and functions

source("TMC_seg022_Functions.R")        # Non-standard functions
source("TMC_seg030_Style.R")            # Define style (colors, lines, ...)

# ---------------------------------------------------------------------------

#  Load additional experimental functions 
#  

#  Next sections takes everything from folder ../func
#func.list <- dir("../func/")
#func.list.n <- length(func.list)
#if (func.list.n > 0)
#{ for (i in 1:func.list.n) 
#  { 
#    cat("\nLoading from /func", func.list[i])
#    source(paste("../func/", func.list[i], sep=""))
#  }
#}
#ls()

#  Selected functions (new or modified versions in ../func)
#source("../func/F_Compose.R")
#source("../func/F_Extract.R")
#source("../func/F_Infoblock.R")
#source("../func/F_tmc.master.R")
#source("../func/F_tmc0_V3.R")
#source("../func/F_tmc1.R")
#source("../func/F_TukeyWW.R")
#source("../func/F_chi2.PNV.tr.lms.R")

# ---------------------------------------------------------------------------
#  Check error condition at this point

#  Disabled. Makes only sense if warnings() can be reset to NULL at programme 
#  start, otherwise obsolete warnings can stop the run.

#if (is.null(warnings()))
#{ cat("\n Libraries and functions successfully loaded \n") } else
#{ 
#  cat("\n ++++++",
#      "\n ++++++ Problem encountered while loading libraries and functions",
#      "\n ++++++ Execution is stopped",
#      "\n ++++++",
#      "\n") 
#  print(warnings())

#  stop("++++++  Execution stopped")
#}

# ---------------------------------------------------------------------------

#  Create identification of this analysis
RunId <- paste(substr(time.start,  1, 10), "_", 
               substr(time.start, 12, 13), 
               substr(time.start, 15, 16), 
               substr(time.start, 18, 19), sep="")

#  Logfile containing (nearly) all run parameters
logfile      <- paste("../log/", RunId,".txt", sep="")      #  txt version
logfile.rda  <- paste("../log/", RunId,".RData", sep="")    #  RData
                                                            #  only simulation

#  --------------------------------------------------------------------
#  General constants
# ----------------------------------------------------------------------       

fastnull     <- 1.e-10
fastnull.chi <- 0.1

# ---------------------------------------------------------------------------
#  Produce a new data set with first values? If so, provide
#  ... the column containing the patient identification
spalte.i <- NA

#  ... the column containing the date of analysis (or the patient age
#  at the time of analysis)
spalte.d <- NA

#   ... the name of the new file with first values 
DataFileFirstValue <- NA 

#  If spalte.i or spalte.d or DataFileFirstValue == NA:
#  no file with first values is produced

# -------------------------------------------------------------------------

#  Values for non-mandatory data columns 
spalte.oh   <- NA      #  data column outpatient/hospitalized
spalte.dev  <- NA      #  data column device
spalte.dz   <- NA      #  data column date-time
use.oh      <- NA      #  select outpatient/hospitalized
use.dev     <- NA      #  select device

# -------------------------------------------------------------------------
#  Factor for constructing surrogate values for values < detection/
#  determination limit
s.fact <- 0.67

#  Option for dealing wit "< DL" in the data
DL.option <- 1          # replace values of the form "< DL" with 
                        # max(DL) * s.fact, return detect.limits.max
                        # More options available, but not recommended

# -------------------------------------------------------------------------
#  Draw a subsample of size ...
subsample.n <- NA

# -------------------------------------------------------------------------
#       Date selection: use only data obtained before / after 
split.date <- NA                # no split 
split.time <- NA                # no split
# split.date <- "04.02.2019"    # "dd.mm.yyyy"
# split.time <- "13:25"         # "hh:mm"

# split.date.n <- as.numeric(mdy.date(02, 04, 2019)) #  split example

use.split      <- NA        # split to use

# -------------------------------------------------------------------------
#   (6) Daytime selection: use only data obtained between  ... 
#      (no selection: set all 4 values to NA)
ana.hour.min <- 0
ana.minu.min <- 0 

#  (7) and ...
ana.hour.max <- 24
ana.minu.max <- 00

# -------------------------------------------------------------------------
#  (7a) Weekday selection:
use.wday <- "all"       #  "all"   or a subset of 
                        #  c("mo", "tu", "we", "th", "fr", "sa", "su")
                        #  use.wday <- c("sa", "su")


# -------------------------------------------------------------------------
#  Degrees of freedom for estimates of all 3 PND parameters

#  df to pay for estimation  = # of parameters
#  df to pay for constraints = 1
df.est    <- 3

#  df to pay for constraints
df.con    <- 1

#  Df to pay must be subtracted from number of bins when assessing the chi^2 
#  value 

# -------------------------------------------------------------------------
#     Histogram breaks start and width, maximimum will always be calculated.
#     Not usually needed, histogram is by default automatically created,
#     following rules in the next section
#     NA in both variables: automatic calculation
break.min.user   <-  NA       # NA: automatic selection
break.delta.user <-  NA

# -------------------------------------------------------------------------

#  Standard minimum number of bins in histogram. Default value for data which
#  has enough bins. Will automatically be reduced if not enough bins available.
#  Former variable x.bins.n removed. Now only bins.n.min effective. 15.04.2021
bins.n.min <- df.est + df.con + 2        #  @@@ Test 03.03.2031
bins.n.min <- df.est + df.con + 4        #  Standard  df.est + df.con + 4

#  Standard maximum number of bins in histogram. Is used to prevent excessively
#  many bins that require too much analysis time.
# bins.n.max <- 50 
bins.n.max <- 100           # 23.04.2021 

#  Minimum number of values per bin
#n.per.bin.min <- 50
n.per.bin.min  <- 10        #  10.04.2021, 23.04.2021
 
#  Truncation intervals used for estimation must contain at least 
#  x.tr.bins.min   bins
#x.tr.bins.min <- df.est + df.con + 1    #  Standard  df.est + df.con + 1
x.tr.bins.min <- df.est + df.con + 2    #  23.04.2021

#  Truncation intervals used for TMC estimation must contain at least 
#  a proportion of ... of all data
#  This limit describes the length of the truncation interval!
# x.tr.prop.min <- 0.35    #  so festgelegt 24.02.2021
# x.tr.prop.min <- 0.50    #  so festgelegt 22.04.2021 / 23.04.2021
x.tr.prop.min <- 0.60      #  fixed 16.05.2021

#  Truncation intervals used for TMC estimation may contain at most 
#  a proportion of ... of all data
#x.tr.prop.max <- 0.85      #  20.05.2020
x.tr.prop.max <- 0.95      #  03.03.2031

#  Limit for using a reduced dataset in QQW: 
red.limit <- 1000

# -------------------------------------------------------------------------
#  Plot layout
#
par.tcl <- 0.5            #  0.5: tickmarks  inside the graph area
                          # -0.5: tickmarks outside the graph area
par.las <- 1              # 0: all labels parallel to the axis
                          # 1: all labels horizontal

# -------------------------------------------------------------------------
#  When plotting histograms with x range limited by x.clip: use
#  the limits as specified or move them to the next value in x.breaks?

x.clip.type <- "as.specified"     #  "coincide"

# -------------------------------------------------------------------------
# Smooth the empirical histogram? Useful if data is rounded by "go to the 
# even number". At most 1 option may be selected.

smooth.hist1 <- TRUE       #  5 point moving average / 23.04.2021
smooth.hist2 <- FALSE      #  use kernel density estimate for smoothing

# -------------------------------------------------------------------------
#  PND properties
#  If lambda.min = lambda.max, this value will be used as fixed value 
#  of lambda    
lambda.min <-    0.0 # Minimal allowed lambda
lambda.max <-    0.0 # Maximal allowed lambda
       
# -------------------------------------------------------------------------
#  Parameters for QQW
#  This will be changed in 040_ProcessSettings if the user restricts lambda 
#  such that this sequence makes no sense

lambda.seq <- c(0.0, 0.1, 1.0)

# -------------------------------------------------------------------------
#  Parameters for TMC

#  Compensation factor for length of truncation interval (worse chi2.per.df
#  is compensated if interval is larger)
#  l.fact = 0 means no compensation
#  
l.fact <- 0.0              #  Default in last published version: ---
                           #  LEAVE AT 0!!

#  Weighting factor for for penalty term "negative estimated prevalence"  
#  Controls degree of penalisation, p.fact <- 0 means no penalisation 
p.fact <- 0.0            

#  Weighting factor for penalty term "RL no in empirical [x.Q1, x.Q2]"
#  Controls degree of penalisation, r.fact <- 0 means no penalisation 
#  
r.fact <- 100              #  Default set by experimentation

#  Weighting factor for penalty term "too large prediction"  
#  Controls degree of penalisation, w.fact <- 0 means no penalisation 
#  
w.fact <- 1.0              #  Default in last published version: 0.1
                           #  1.0 set because of simulation study 

# -------------------------------------------------------------------------
#  TMC: Fit citerion for the choice of of a truncation interval
p.fit.min <- 0.20          #  30.03.2020

#  Accepted range for estimated prevalence
prev.acc.lo <- -0.05     #  -0.02
prev.acc.hi <-  1.05

#  Use runs test for residuals as additional component of the solution score?
crit123456 <- TRUE

#  p level for runs test. Note that observations are not independent.
#crit6.p <- 0.005
crit6.p <- 0.05      #  10.04.2021

# -------------------------------------------------------------------------
#  Parameters for the extended Tukey approach
IQR.fact     <- 1.0    #  Tukey default: 1.5

iter.max.tuk <- 5      #  Tukey default: 1  ( <=> no iteration)    

# -------------------------------------------------------------------------
#  False positive rate for confidence intervals 
#  (1-alpha = coverage probability)
alpha <- 0.05

# -------------------------------------------------------------------------
#  When analysing a sequence of replicates: first replicate? 
r.start <-  NA     # (NA: no replicates)

#  When analysing a sequence of replicates: last replicate?
r.ende  <-  NA    # (NA: no replicates)

# -------------------------------------------------------------------------
#  Kernel density estimation
kernel.n     <- 4096   # Number of support points  Pr.lo <- 0.001 
Pr.lo        <- 0.001  # Lower quantile of the interval approximated by kde 
Pr.hi        <- 0.999  # Upper quantile 

qtype        <- 4      # Type of quantile to calculate,
                       # see RLib\Quantile.R

# -------------------------------------------------------------------------
#  Bootstrappimg
nbs          <-  0     # Number of bootstrap replicates for tolerance intervalsle
                       # 0: no TI (instead asymptotic CI)                   
                       # temporarily deactivated!

# -------------------------------------------------------------------------
#  Results from which methods shall appear in the summmary table per data 
#  file?
#  "npa" will be removed for data not containing the grp variable 
#  (typically only present in simulated data) 
gtab.list   <- c("npa", "qqw", "tmc", "tmu", "tuk")   # WW
gtab.list   <- c("tmc")                               # Usr 
#
gtab.list.n <- length(gtab.list)

#  Results from which methods shall appear in the summmary table per scenario?
meth.list   <- gtab.list
meth.list.n <- length(meth.list)

#  Which results are to be plotted in the result per stratum?
plot.tmc <- TRUE

# -------------------------------------------------------------------------
#  Which estimation methods shall be executed?

do.bha <- "bha" %in% gtab.list
do.npa <- "npa" %in% gtab.list    # possible only for generated data
do.qqw <- ("qqw" %in% gtab.list) | ("tmc" %in% gtab.list)
do.tmc <- ("tmc" %in% gtab.list) 
do.tmu <- ("tmu" %in% gtab.list)
do.tuk <- ("tuk" %in% gtab.list)

# -------------------------------------------------------------------------
#  Methods for which to plot the age-RL dependency  --- OBSOLETE
Verlauf.Meth1 <- "tmc"
if (do.tmu) 
{ Verlauf.Meth2 <- "tmu" } else
{ Verlauf.Meth2 <- NA }

#  Which plots? Keyword is interpreted in TMC_seg045_PlotRequest.R
 
#plot.level   <- "all"    # Do all plots - not recommended for routine
plot.level <- "auto"      # Most relevant plots. Automatic distinction
                          # between the analysis of single files and 
                          # the analysis of file sequences (simulation).

#  Plot details in certain plots?
plot.details <- FALSE      # TRUE: legend, gridlines, infoblock,
                           # especially in plots 150.10, 160.010
if (user == "WW") { plot.details <- TRUE } 

# -------------------------------------------------------------------------
#   If no age axis parameters for the age axis in plots 150.10, 160.10, set
#   corresponding variables to NA
if (!exists("age.clip.min"))
{ age.clip.min   <- NA
  age.clip.max   <- NA
  age.clip.by1   <- NA
  age.clip.by2   <- NA
}

# -------------------------------------------------------------------------
#   If no axis parameters for the RL axis in plots 150.10, 160.10, set
#   corresponding variables to NA
if (!exists("RL.clip.min"))
{ RL.clip.min   <- NA
  RL.clip.max   <- NA
  RL.clip.by1   <- NA
  RL.clip.by2   <- NA
}

# -------------------------------------------------------------------------
#  For validation only: axis limits in fig 202.010

RL1.clip.min <- NA
RL1.clip.max <- NA
RL1.clip.by1 <- NA
RL1.clip.by2 <- NA

RL2.clip.min <- NA
RL2.clip.max <- NA
RL2.clip.by1 <- NA
RL2.clip.by2 <- NA


# -------------------------------------------------------------------------
#  Graphics file format? (emf, bmp, ...)
figtype <- "bmp"

#  End of default settings
# =================================================================

if (print.log.message) { cat("%%%   TMC_seg15_DefaultSettings  End\n") }

