#  TMC_seg105_Analysis_tmc.R
#
#  07.04.2021 crit1 not used if values < DL exist 
#  15.02.2021 Start
# ==============================================================================
  tab.tmc0 <- tmc.master(x, x.hist, tab.qqw, 
                         theta.fix, theta.est, idx.fix, idx.est,
                         lambda.min, lambda.max, 
                         df.est, df.con, p.fit.min,
                         l.fact, p.fact, r.fact, w.fact, 
                         x.Q1, x.Q2, RL1.p, RL2.p, fastnull, fastnull.chi,                     
                         print.log.message,
                         unlist(tab.npa["x.RL1.npa"]), 
                         unlist(tab.npa["x.RL2.npa"]), 
                         xsupp, gencol, kdecol, tmccol, fig100.015)

  #  Assessment of TMC result
  #  Ideally, the solution fulfills all 7 criteria (fit + crit 1-6).
  #  If there is no such solution, the final solution is found by 
  #  as follows:
  #  solution 1 is better than solution 2, if it has more criteria
  #  fulfilled,
  #  if two solutions have the same number of fulfulled criteria,
  #  the one with higher p.fit is better

  #  Calculate assessment criteria
  #  Estimated RLs in [x.Q1, x.Q2]?
  #  Consider crits 1 only if no values < DL, because x.Q1 is
  #  very unreliable if values < DL exist
  if (is.na(detect.limits.max))
  { crit1 <- unname(x.Q1 <= tab.tmc0["x.RL1.tmc"]) } else
  { crit1 <- TRUE } 
    
  crit2 <- unname(x.Q2 >= tab.tmc0["x.RL2.tmc"])

  #  Estimated prevalences in [prev.acc.lo, prev.acc.hi]?
  crit3 <- unname((prev.acc.lo <= tab.tmc0["prev.l.tmc"])) &
                   unname((tab.tmc0["prev.l.tmc"] <= prev.acc.hi))  
  crit4 <- unname((prev.acc.lo <= tab.tmc0["prev.c.tmc"])) &
                   unname((tab.tmc0["prev.c.tmc"] <= prev.acc.hi))  
  crit5 <- unname((prev.acc.lo <= tab.tmc0["prev.r.tmc"])) &
                   unname((tab.tmc0["prev.r.tmc"] <= prev.acc.hi))
  crit6 <- NA
                    
  #  Basic solution score
  solution.score <- crit1 + crit2 + crit3 + crit4 + crit5

  NoTmcSolution <- (unname(tab.tmc0["p.fit"]) < p.fit.min) |
                           (solution.score < 5) 

  #  More sophisticated solution score, if desired
  
  if (crit123456)
  { #  Solution score is calculated including crit6 (random 
    #  fluctuation of residuals)
    temp.tmc0 <- chi2trunc(x.hist,tab.tmc0["x.tr.lo"],
                             tab.tmc0["x.tr.hi"],
                             sum(x <  tab.tmc0["x.tr.lo"]), 
                             sum(x >= tab.tmc0["x.tr.hi"]),
                             x.Q1, x.Q2, RL1.p, RL2.p,
                             tab.tmc0["lambda.tmc"],
                             tab.tmc0["mue.tmc"],
                             tab.tmc0["sigma.tmc"],
                             df.est, df.con,
                             l.fact, p.fact, r.fact, w.fact, 
                             opt.crit.only=FALSE,fastnull=fastnull)
          
    sign <- 1.0 * (temp.tmc0$tab["diff"] <= 0)          
    runstest <- runs.test(sign, exact=FALSE, alternative="two.sided")

    #  p level for significance reduced because observations are not
    #  independent 
    crit6 <- unname((runstest["p.value"] > crit6.p))
  
    solution.score <- solution.score + crit6  
    NoTmcSolution <- (unname(tab.tmc0["p.fit"]) < p.fit.min) |
                             (solution.score < 6)
  } 

  tab.tmc0 <- c(tab.tmc0, sol.score=solution.score)
          
  if (print.log.message) { cat("%%%   TMC_seg100_Analysis 1210\n") }

  #  If this is the first loop cycle, store actual 
  #  result  (to get a result at all)
  if (first.cycle)
  { 

    if (print.log.message) { cat("%%%   TMC_seg100_Analysis 1220\n") }
  
    tab.tmc     <- tab.tmc0
    temp.tmc    <- temp.tmc0  
  }

  #  If this is not the first loop cycle (which means that previous
  #  solutions were not satisfactory), compare actual 
  #  result with previous and keep the better
  if (!first.cycle)
  { 
    if (print.log.message) { cat("%%%   TMC_seg100_Analysis 1230\n") }

    #cat("\n [Analysis_tmc] Comparison of tab.tmc0 and tab.tmc\n") 

    #temp <- matrix(c(tab.tmc0["x.RL1.tmc"], tab.tmc0["x.RL2.tmc"],
    #tab.tmc0["p.fit"], tab.tmc0["opt.crit"], 
    #tab.tmc0["x.tr.prop"], tab.tmc0["sol.score"],
    #tab.tmc0["RL1.pen"], tab.tmc0["RL2.pen"], 
    #tab.tmc["x.RL1.tmc"], tab.tmc["x.RL2.tmc"],
    #tab.tmc["p.fit"], tab.tmc["opt.crit"], 
    #tab.tmc["x.tr.prop"], tab.tmc["sol.score"],
    #tab.tmc["RL1.pen"], tab.tmc["RL2.pen"]), 
    #byrow=TRUE, nrow=2)
    #dimnames(temp) <- list(c("tmc0", "tmc"), c("RL1", "RL2", 
    #                               "p.fit", "opt.crit", "x.tr.prop",
    #                               "sol.score", "RL1.pen", "RL2.pen"))
    # print(temp)

    #  If scores are identical, **opt.crit** decides 
    #  (with bad fit, p.fit is unreliable)
    if (tab.tmc0["sol.score"] == tab.tmc["sol.score"])
    { # Both scores are identical
      if (tab.tmc0["opt.crit"] < tab.tmc["opt.crit"])
      { # tmc0 is better
        tab.tmc  <- tab.tmc0
        temp.tmc <- temp.tmc0
      }
    } 

    #  Scores differ, solution with higher score is better
    #  @@ To discuss: what if solution with higher score has worse fit?
    if (tab.tmc0["sol.score"] > tab.tmc["sol.score"])
    { # tab.tmc0 is better
      tab.tmc  <- tab.tmc0
      temp.tmc <- temp.tmc0
    }
    # No action needed, if score(tab.tmc) > score(tab.tmc0)
  }

  first.cycle <- FALSE             

  #  Check: which decision taken?
  #cat("\n [Analysis] p.fit of actual optimum ", tab.tmc["p.fit"],
  #    "\n            score of actual solution", tab.tmc["sol.score"],
  #    "\n            iti                     ", iti,
  #    "\n")

  #  Report solution status
  #cat("\n [105_tmc] p.fit of actual optimum ", tab.tmc["p.fit"],
  #    "\n           score of actual solution", tab.tmc["sol.score"],
  #    "\n           iti                     ", iti,
  #    "\n           NoTmcSolution           ", NoTmcSolution,
  #    "\n")
